@@ -1,6 +1,6 @@
-package Pcore::Whois v0.3.2;
+package Pcore::Whois v0.4.0;
 
-use Pcore -class, -const;
+use Pcore -dist, -class, -const;
 use Pcore::Util::Scalar qw[blessed];
 use Pcore::Whois::Data qw[:CONST];
 use Pcore::Whois::Server;
